Release History
===============

0.1.2 - 27 September 2013
-------------------------

* Corrected various problems under Windows

* Added a Global file tree, to show files not in the current project
  directory

0.1.1 - 26 September 2013
-------------------------

* Added overall coverage display and tracking.

0.1.0 - 24 September 2013
-------------------------

Initial public release.
